@@ -2,8 +2,6 @@
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import Pool, PoolMeta
 
-__all__ = ['InvoiceLine']
-
 
 class InvoiceLine(metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
@@ -14,8 +12,7 @@ class InvoiceLine(metaclass=PoolMeta):
         SubscriptionLine = pool.get('sale.subscription.line')
         name = super(InvoiceLine, self).origin_name
         if isinstance(self.origin, SubscriptionLine):
-            name = (self.origin.subscription.reference
-                or self.origin.subscription.rec_name)
+            name = self.origin.subscription.rec_name
         return name
 
     @classmethod
